
global output ""

use ${output}tagged_final.dta, clear

/*

***** VARIABLE DEFINITIONS / CALCULATIONS *****

vl_change = total appreciation – percent predicted
origin_yr = year of loan origination
loan_age = time in years from origination to termination
loan_age_quad = loan age squared
loan_age_yr = time in 
fico_orig = FICO score at origination
fico_change = change in FICO score from origination to termination
married = dummy indicating if the borrower was married (1 = married , 0 = single)
male = dummy variable indicating if the borrower was male (1 = male, 0 = female)
borr_age = age of borrower
rpr_set_aside =  $ amount set aside for repairs
max_claim_amount = max claim amount (in 1,000's)
zip_price_diff = (property appraisal amount at origination)/(median value of properties in the zipcode at the time of origination)
metro_price_diff = (property appraisal amount at origination)/(median value of properties in the metro area at the time of origination)
mx_clm_amnt150_dummy = dummy indicating whether the max claim amount was <= $150,000
g mx_clm_amnt150_inter = mx_clm_amnt150_dummy * max_claim_amount
mca_over150_minus150 = max_claim_amount - 150 if mx_clm_amnt150_dummy ==1 
variables ending in _post2008 are variables (indicated by the rest of the variable name) multiplied by a dummy variable indicating if the loan originated after 2008
frm_post_2008 = dummy variable indicating if a loan was a fixed rate mortgage originated after 2008
fm_pct_cashdd = ratio determined by dividing first month cash draw downs (firstmonth) by the initial principal limit (init_prncpl_lmt).
arm = dummy variable indicating an adjustable rate mortgage
arm_pct_cashdd = arm * fm_pct_cashdd * post_2008 
pre_2009 = dummy variable indicating a loan originated before 2009
g pct_cashdd_pre_2009 = fm_pct_cashdd * pre_2009
term_loan = dummy indicating a term loan
tenure_loan = dummy indicating a ternure loan
percent_predic = percent predicted change in home value

*/

*** All Loans
preserve

eststo: regress vl_change 
eststo: regress vl_change i.origin_yr loan_age
eststo: regress vl_change i.origin_yr loan_age loan_age_quad
eststo: regress vl_change i.origin_yr i.loan_age_yr
eststo: regress vl_change i.origin_yr loan_age loan_age_quad fico_orig fico_change
eststo: regress vl_change i.origin_yr loan_age loan_age_quad married male borr_age 
eststo: regress vl_change i.origin_yr loan_age loan_age_quad rpr_set_aside
eststo: regress vl_change i.origin_yr loan_age loan_age_quad max_claim_amount zip_price_diff metro_price_diff
eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008
eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150
eststo: regress vl_change i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 term_loan tenure_loan
eststo: regress vl_change i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change
eststo: regress vl_change i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change

esttab using ${output}`Y'_spec2_allterminations_zip.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 2 - All Terminations)
esttab using ${output}`Y'_spec2_allterminations_zip.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 2 - All Terminations)
esttab using ${output}`Y'_spec2_allterminations_tstat_zip.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 2 - All Terminations)
esttab using ${output}`Y'_spec2_allterminations_tstat_zip.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 2 - All Terminations)

eststo clear

restore

*** REO Sale

preserve

keep if FailureType==3

eststo: regress vl_change 
eststo: regress vl_change i.origin_yr loan_age
eststo: regress vl_change i.origin_yr loan_age loan_age_quad
eststo: regress vl_change i.origin_yr i.loan_age_yr
eststo: regress vl_change i.origin_yr loan_age loan_age_quad fico_orig fico_change
eststo: regress vl_change i.origin_yr loan_age loan_age_quad married male borr_age 
eststo: regress vl_change i.origin_yr loan_age loan_age_quad rpr_set_aside
eststo: regress vl_change i.origin_yr loan_age loan_age_quad max_claim_amount zip_price_diff metro_price_diff
eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008
eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150
eststo: regress vl_change i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 term_loan tenure_loan
eststo: regress vl_change i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change
eststo: regress vl_change i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change

esttab using ${output}`Y'_spec2_foreclosed_zip.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 2 - REO Sale)
esttab using ${output}`Y'_spec2_foreclosed_zip.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 2 - REO Sale)
esttab using ${output}`Y'_spec2_foreclosed_tstat_zip.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 2 - REO Sale)
esttab using ${output}`Y'_spec2_foreclosed_tstat_zip.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 2 - REO Sale)

eststo clear

restore

*** Borrower Sale

preserve

drop if FailureType==3

eststo: regress vl_change 
eststo: regress vl_change i.origin_yr loan_age
eststo: regress vl_change i.origin_yr loan_age loan_age_quad
eststo: regress vl_change i.origin_yr i.loan_age_yr
eststo: regress vl_change i.origin_yr loan_age loan_age_quad fico_orig fico_change
eststo: regress vl_change i.origin_yr loan_age loan_age_quad married male borr_age 
eststo: regress vl_change i.origin_yr loan_age loan_age_quad rpr_set_aside
eststo: regress vl_change i.origin_yr loan_age loan_age_quad max_claim_amount zip_price_diff metro_price_diff
eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008
eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150
eststo: regress vl_change i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 term_loan tenure_loan
eststo: regress vl_change i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change
eststo: regress vl_change i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change

esttab using ${output}`Y'_spec2_nonforeclosed_zip.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 2 - Borrower Sale)
esttab using ${output}`Y'_spec2_nonforeclosed_zip.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 2 - Borrower Sale)
esttab using ${output}`Y'_spec2_nonforeclosed_tstat_zip.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 2 - Borrower Sale)
esttab using ${output}`Y'_spec2_nonforeclosed_tstat_zip.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 2 - Borrower Sale)

eststo clear

restore

** REO Sale Dependent

preserve

gen foreclose=0
replace foreclose=1 if FailureType==3

eststo: logit foreclose percent_predic
eststo: logit foreclose i.origin_yr loan_age
eststo: logit foreclose i.origin_yr loan_age loan_age_quad
eststo: logit foreclose i.origin_yr i.loan_age_yr
eststo: logit foreclose i.origin_yr loan_age loan_age_quad fico_orig fico_change
eststo: logit foreclose i.origin_yr loan_age loan_age_quad married male borr_age 
eststo: logit foreclose i.origin_yr loan_age loan_age_quad rpr_set_aside
eststo: logit foreclose i.origin_yr loan_age loan_age_quad max_claim_amount zip_price_diff metro_price_diff
eststo: logit foreclose i.origin_yr loan_age loan_age_quad zip_price_diff mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008
eststo: logit foreclose i.origin_yr loan_age loan_age_quad zip_price_diff mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150
eststo: logit foreclose i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 term_loan tenure_loan
eststo: logit foreclose i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change
eststo: logit foreclose i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
eststo: logit foreclose percent_predic i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change
eststo: logit foreclose percent_predic i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change

esttab using ${output}`Y'_spec2_foreclosed_dependent.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 3 - REO Sale Dependent)
esttab using ${output}`Y'_spec2_foreclosed_dependent.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 3 - REO Sale Dependent)
esttab using ${output}`Y'_spec2_foreclosed_dependent_tstat.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 3 - REO Sale Dependent)
esttab using ${output}`Y'_spec2_foreclosed_dependent_tstat.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 3 - REO Sale Dependent)

eststo clear

restore

end

