clear all
clear matrix
program drop _all


program define main
    macros
    generaldatacreation
    appraisalhpi_z
    salehpi_z
    vlchange_and_hpimerge
    outliers
    tabulations
    specification1_z
    specification2_z
end


program define macros
	global data ""
	global output ""
end

program define generaldatacreation


	*** Generate General Sale Price Change Dataset

	use ${output}tagged_final.dta, clear


	* Remove duplicate entries, missing dates, and entries without value transfers
	sort prop_id deedsdate
	drop if sr_seller==sr_seller[_n-1] & sr_buyer==sr_buyer[_n-1] & deedsdate==deedsdate[_n-1] & sr_val_transfer==sr_val_transfer[_n-1]
	drop if deedsdate==.
	drop if sr_val_transfer<2 

	* Sum value transfers of a property that are within one month of each other, as they are properties where the value is being split across several owners/records
	sort prop_id deedsdate
	gen date_diff=deedsdate-deedsdate[_n-1] if prop_id==prop_id[_n-1]
	gen date_diff2=deedsdate-deedsdate[_n+1] if prop_id==prop_id[_n+1]
	replace date_diff2=-1*date_diff2
	gen one_month=0
	replace one_month=1 if date_diff<32 & date_diff!=.
	replace one_month=1 if date_diff2<32 & date_diff2!=. & one_month==0

	sort prop_id deedsdate
	gen change=0
	replace change = 1 if date_diff>32 & date_diff2<32
	keep if one_month==1
	drop one_month

	by prop_id, sort: gen which_sale=_n if change==1

	sort prop_id deedsdate
	gen diff2=deedsdate-deedsdate[_n-1] if prop_id==prop_id[_n-1]
	replace which_sale=which_sale[_n-1] if change==0

	list prop_id deedsdate change which_sale in 1/50

	destring deedsyear, replace
	sort prop_id deedsdate
	egen sale_price2=total(sr_val_transfer), by(prop_id which_sale)
	list prop_id deedsdate change which_sale sale_price* in 100/200 

	by prop_id, sort: gen nvals=_n==1
	keep if nvals ==1
	keep sale_price2 prop_id deedsdate

	merge 1:m prop_id deedsdate using ${output}tagged_final.dta
	drop _merge
	drop sale_price
	gen sale_price=sr_val_transfer

	* Alter sale price variable to take multiple record sales into consideration
	replace sale_price=sale_price2 if sale_price2!=.

	* Keep only the first record of a multi-record transfer
	sort prop_id deedsdate
	gen date_diff=deedsdate-deedsdate[_n-1] if prop_id==prop_id[_n-1]
	drop if date_diff<32

	* Tag liens to hud
	drop lien_to_hud
	g lien_to_hud = regexm(sr_lndr_first_name_1, "HUD") | regexm(sr_lndr_first_name_2, "HUD") | regexm(sr_lndr_first_name_3, "HUD") 

	sort prop_id deedsdate
	drop if deedsdate==.

	* Note time difference between HECM origination date and the origination date noted by Deeds
	gen clsng_diff=deedsdate-clsng_dt
	replace clsng_diff=clsng_diff*(-1) if clsng_diff<0

	save temp1.dta, replace

	gen origination_diff=""
	replace origination_diff="1 week or less" if clsng_diff<8
	replace origination_diff="1 week to 6 weeks" if clsng_diff>7 & clsng_diff<43
	replace origination_diff="Over 6 weeks" if clsng_diff>42

	keep if clsng_diff<43

	sort prop_id clsng_diff
	by prop_id, sort: gen deed_match=_n

	keep if deed_match==1
	keep prop_id origination_diff deedsdate
	rename deedsdate origination_date
	merge 1:m prop_id using temp1.dta
	keep if _merge==3
	drop _merge

	rm temp1.dta

	sort prop_id clsng_diff
	by prop_id, sort: gen deed_match=_n

	drop if deedsdate<clsng_dt & deed_match!=1
	drop deed_match

	* Keep only HECM records that fall within deed records
	format %td deedsdate
	gen status_yr=year(deedsdate)
	gen status_month=month(deedsdate)
	sort prop_id clsng_diff
	by prop_id, sort: gen deed_match=_n

	* Prepare Termination type tagging for each loan
	* Note: Variable FailureType established in "kaplan_mier_plots_&tabs.do"

	by prop_id, sort: gen temp=_N
	gen term_dummy=0
	replace term_dummy=1 if deed_cat!="Other Transfer" & deed_match>1
	replace term_dummy=1 if temp==1
	keep if term_dummy==1

	replace deed_cat="No Transactions" if deed_cat=="Other Transfer" | temp==1

	gen foreclosure2=0
	replace foreclosure2=1 if deed_cat=="Foreclosure"

	g foreclosure_wprice=0
	replace foreclosure_wprice=1 if foreclosure2==1 & sale_price>0

	replace foreclosure_wprice=. if foreclosure2!=1

	replace deed_cat="No Transactions" if deed_cat=="Other Transfer" | temp==1

	replace new_status="After 2012 Claim" if status_yr>2012

	gen reason=deed_cat
	replace reason="" if reason=="No Transactions"
	gen FailureType=0
	replace FailureType=1 if deed_cat=="Sale W/ Price"
	replace FailureType=2 if deed_cat=="Refinance"
	replace FailureType=3 if deed_cat=="Foreclosure"

	* Note if a property is being sold directly after a foreclosure 
	gen market_tran=0
	replace market_tran=1 if foreclosure2==1 & buy_temp2==0 & buy_temp==0 & sale_price>0
	replace market_tran=1 if countyseller>0 & buy_temp2<1 & sale_price>0

	keep if FailureType==1 | market_tran==1
	drop if deedsdate<= origination_date

	sort prop_id deedsdate
	drop deed_match
	by prop_id, sort: gen deed_match=_n==1
	by prop_id, sort: gen deed_count=_N
	g second_sale=0
	replace second_sale=1 if deed_count>1

	keep if deed_match==1

	* Create property appraisal variable
	gen orig_aprsl=prprty_aprsl_vl
	replace orig_aprsl=prprty_aprsl_vl_2 if orig_aprsl==.

	* Create property price change variable and sale date variables
	gen sale_price_change=0
	replace sale_price_change=sale_price - orig_aprsl
	drop sale_date
	gen sale_date=deedsdate

	* Create Max Claim Amount variable
	g max_claim_amount=max_clm_amt
	replace max_claim_amount=max_clm_amt_2 if max_claim_amount==.

	* Create Co Borrrower age at endorsement
	g coborr_birth_year=year(coborr_brth_dt_1)
	gen origin_yr=year(origination_date)
	g coborr_age=origin_yr-coborr_birth_year

	* Create Tag for termination type
	*** deedoutcome variable guide: "D" = Death "M" = Borrower Moved "P" = Borrower Paid "O" = Other "F" = Foreclosure "H" = Short Sale "L" = Deed In Lieu "R" = Refinance "C" = Claim

	gen deedoutcome=""
	replace deedoutcome="D" if cs_sub_sts=="06-31"
	replace deedoutcome="M" if cs_sub_sts=="06-32"
	replace deedoutcome="P" if cs_sub_sts=="06-33"
	replace deedoutcome="O" if cs_sub_sts=="06-34"
	replace deedoutcome="F" if cs_sub_sts=="06-35"
	replace deedoutcome="H" if cs_sub_sts=="06-36"
	replace deedoutcome="F" if cs_sub_sts=="06-40"
	replace deedoutcome="L" if cs_sub_sts=="06-41"
	replace deedoutcome="R" if cs_sub_sts=="06-42"
	replace deedoutcome="F" if cs_sub_sts=="06-43"
	replace deedoutcome="H" if cs_sub_sts=="06-44"
	replace deedoutcome="C" if cs_sub_sts=="06-45"
	rename deedoutcome HECMoutcome


	keep prop_id sale_price_change sale_date orig_aprsl origination_date FailureType zip clsng_dt appl_rcvd_dt borr_age_endrs rt_typ borr_gender coborr_brth_dt_1 max_claim_amount fm_pct_cashdd upb_amt mndtry_oblgtns_amt rpr_set_aside fm_pct_cashdd loan_typ coborr_age HECMoutcome

	sort prop_id sale_date

	* Create origination date
	gen origin_yr=year(origination_date)
	gen loan_age=0
	replace loan_age=sale_date-origination_date
	replace loan_age=loan_age/365
	gen loan_age_yr=.
	replace loan_age_yr=1 if loan_age<=1
	replace loan_age_yr=2 if loan_age>1 & loan_age<=2
	replace loan_age_yr=3 if loan_age>2 & loan_age<=3
	replace loan_age_yr=4 if loan_age>3 & loan_age<=4
	replace loan_age_yr=5 if loan_age>4 & loan_age<=5
	replace loan_age_yr=6 if loan_age>5 & loan_age<=6
	replace loan_age_yr=7 if loan_age>6 & loan_age<=7
	replace loan_age_yr=8 if loan_age>7 & loan_age<=8
	replace loan_age_yr=9 if loan_age>8 & loan_age<=9
	replace loan_age_yr=10 if loan_age>9 & loan_age<=10
	replace loan_age_yr=11 if loan_age>10 & loan_age<=11
	replace loan_age_yr=12 if loan_age>11 & loan_age<=12
	replace loan_age_yr=13 if loan_age>12 & loan_age<=13
	replace loan_age_yr=14 if loan_age>13 & loan_age<=14
	replace loan_age_yr=15 if loan_age>14 & loan_age<=15
	replace loan_age_yr=16 if loan_age>15

	* Keep only first sale record as it contains all the information needed
	sort prop_id sale_date
	by prop_id, sort: gen nvals=_n==1
	keep if nvals==1
	drop nvals

	save ${output}loan_price_change.dta, replace


end


program define appraisalhpi_z

	*** Gen Appraisal HPI and Credit Scores
	preserve

	gen year=year(appl_rcvd_dt)
	destring year, replace
	gen month=month(appl_rcvd_dt)
	destring month, replace
	merge m:1 zip year month using "${data}Zip_Zhvi_AllHomes.dta"
	keep if _merge==3
	drop _merge
	gen aprsl_hpi=zhvi 
	drop if zhvi==.

	merge m:1 zip year month using ${data}Zillow_median_hv_zip_metro.dta
	drop if _merge==2
	drop _merge
	gen aprsl_median_hv_zip=median_hv_zip
	gen aprsl_median_hv_metro=median_hv_metro

	* Credit data is biannual, alter merge to match accordingly
	replace month=3 if month<=6
	replace month=9 if month<=12 & month>6
	merge 1:1 prop_id year month using ${output}credit_scores_id_merge.dta
	drop if _merge==2

	destring fico, replace
	destring vantage, replace
	forval i=1/4{
	destring fico`i', replace
	destring vantage`i', replace
	}

	* If more than one borrower, create credit score variables that takes the average between all borrowers' credit scores
	gen fico_orig=fico
	replace fico_orig=fico+fico1 if fico1!=.
	replace fico_orig=fico_orig/2 if fico1!=.
	replace fico_orig=fico+fico1+fico2 if fico2!=.
	replace fico_orig=fico_orig/3 if fico2!=.
	replace fico_orig=fico+fico1+fico2+fico3 if fico3!=.
	replace fico_orig=fico_orig/4 if fico3!=.
	replace fico_orig=fico+fico1+fico2+fico3+fico4 if fico3!=.
	replace fico_orig=fico_orig/5 if fico4!=.

	gen vantage_orig=vantage
	replace vantage_orig=vantage+vantage1 if vantage1!=.
	replace vantage_orig=vantage_orig/2 if vantage1!=.
	replace vantage_orig=vantage+vantage1+vantage2 if vantage2!=.
	replace vantage_orig=vantage_orig/3 if vantage2!=.
	replace vantage_orig=vantage+vantage1+vantage2+vantage3 if vantage3!=.
	replace vantage_orig=vantage_orig/4 if vantage3!=.
	replace vantage_orig=vantage+vantage1+vantage2+vantage3+vantage4 if vantage3!=.
	replace vantage_orig=vantage_orig/5 if vantage4!=.

	* Note missing values
	gen missing_fico_orig=0
	replace missing_fico_orig=1 if fico_orig==.
	gen missing_vantage_orig=0
	replace missing_vantage_orig=1 if vantage_orig==.

	* replace missing values with 0
	replace fico_orig=0 if fico_orig==.
	replace vantage_orig=0 if vantage_orig==.

	keep prop_id aprsl_hpi fico_orig vantage_orig aprsl_median_hv_zip aprsl_median_hv_metro missing*
	save ${output}aprsl_hpi.dta, replace
	restore

end

program define salehpi_z

	*** Gen Sale HPI & Credit Scores
	preserve
	gen year=year(sale_date)
	destring year, replace
	gen month=month(sale_date)
	destring month, replace
	merge m:1 zip year month using "${data}Zip_Zhvi_AllHomes.dta"
	* 6,372 dropped due to zip incompatability
	keep if _merge==3
	drop _merge
	gen sale_hpi=zhvi

	merge m:1 zip year month using ${data}Zillow_median_hv_zip_metro.dta
	drop if _merge==2
	drop _merge
	gen sale_median_hv_metro=median_hv_metro
	gen sale_median_hv_zip=median_hv_zip

	drop if zhvi==.

	* Credit data is biannual, alter merge to match accordingly
	replace month=3 if month<=6
	replace month=9 if month<=12 & month>6
	merge 1:1 prop_id year month using ${output}credit_scores_id_merge.dta
	drop if _merge==2


	destring fico, replace
	destring vantage, replace
	forval i=1/4{
	destring fico`i', replace
	destring vantage`i', replace
	}

	* If more than one borrower, create credit score variables that takes the average between all borrowers' credit scores
	gen fico_sale=fico
	replace fico_sale=fico+fico1 if fico1!=.
	replace fico_sale=fico_sale/2 if fico1!=.
	replace fico_sale=fico+fico1+fico2 if fico2!=.
	replace fico_sale=fico_sale/3 if fico2!=.
	replace fico_sale=fico+fico1+fico2+fico3 if fico3!=.
	replace fico_sale=fico_sale/4 if fico3!=.
	replace fico_sale=fico+fico1+fico2+fico3+fico4 if fico3!=.
	replace fico_sale=fico_sale/5 if fico4!=.

	gen vantage_sale=vantage
	replace vantage_sale=vantage+vantage1 if vantage1!=.
	replace vantage_sale=vantage_sale/2 if vantage1!=.
	replace vantage_sale=vantage+vantage1+vantage2 if vantage2!=.
	replace vantage_sale=vantage_sale/3 if vantage2!=.
	replace vantage_sale=vantage+vantage1+vantage2+vantage3 if vantage3!=.
	replace vantage_sale=vantage_sale/4 if vantage3!=.
	replace vantage_sale=vantage+vantage1+vantage2+vantage3+vantage4 if vantage3!=.
	replace vantage_sale=vantage_sale/5 if vantage4!=.

	* Note missing values
	gen missing_fico_sale=0
	replace missing_fico_sale=1 if fico_sale==.
	gen missing_vantage_sale=0
	replace missing_vantage_sale=1 if vantage_sale==.


	* replace missing values with 0
	replace fico_sale=0 if fico_sale==.
	replace vantage_sale=0 if vantage_sale==.

	keep prop_id sale_hpi fico_sale vantage_sale sale_median_hv_zip sale_median_hv_metro missing*
	save ${output}sale_hpi.dta, replace
	restore

end 



program define vlchange_and_hpimerge

	*** Create Value Change Variables and Add HPI & Credit Scores
	gen val_change=sale_price_change/orig_aprsl
	merge 1:1 prop_id using ${output}aprsl_hpi.dta
	keep if _merge==3
	drop _merge
	merge 1:1 prop_id using ${output}sale_hpi.dta
	keep if _merge==3
	drop _merge
	gen hpi_diff=sale_hpi-aprsl_hpi
	gen predic_vl=hpi_diff/aprsl_hpi
	gen vl_change=val_change-predic_vl
	drop if orig_aprsl==999999

end

program define outliers

	*** Drop Outliers

	regress vl_change loan_age_yr origin_yr
	predict resid, residuals
	sort resid
	_pctile resid, p(97)
	return list
	gen p97=r(r1)
	sort resid
	_pctile resid, p(3)
	return list
	gen p3=r(r1)
	drop if resid>=p97 
	drop if resid<=p3

end

program degine tabulations

	preserve
	*** calculate basic price decline by origination year and loan age 
	tab origin_yr, gen(year)
	g val_change_count=1
	collapse (mean) val_change (sum) val_change_count, by(loan_age_yr origin_yr)
	outsheet using ${output}price_decline_allloans.csv, replace
	restore


	*** calculate basic price decline by origination year and loan age for local price increase
	preserve
	keep if hpi_diff>0
	tab origin_yr, gen(year)
	g val_change_count=1
	collapse (mean) val_change (sum) val_change_count, by(loan_age_yr origin_yr)
	outsheet using ${output}price_decline_priceincrease.csv, replace
	restore



	*** calculate basic price decline by origination year and loan age for local price decrease
	preserve
	keep if hpi_diff<0
	tab origin_yr, gen(year)
	g val_change_count=1
	collapse (mean) val_change (sum) val_change_count, by(loan_age_yr origin_yr)
	outsheet using ${output}price_decline_pricedecrease.csv, replace
	restore

	*** calculate basic price decline by origination year and loan age for paidoff loans
	preserve
	drop if FailureType==3
	tab origin_yr, gen(year)
	g val_change_count=1
	collapse (mean) val_change (sum) val_change_count, by(loan_age_yr origin_yr)
	outsheet using ${output}price_decline_notforeclosed.csv, replace
	restore

	*** calculate basic price decline by origination year and loan age for loans that were foreclosed
	preserve
	keep if FailureType==3
	tab origin_yr, gen(year)
	g val_change_count=1
	collapse (mean) val_change (sum) val_change_count, by(loan_age origin_yr)
	outsheet using ${output}price_decline_foreclosed.csv, replace
	restore


end

program define specification1


	***** Change Dependent

	*** All Loans

	preserve

	* (total appreciation – percent predicted)


	* Generate total appreciation variables to match those of the precoded regression
	g percent_val=val_change*100
	g percent_predic=predic_vl*100

	* Borrower= Male (borr_gender==1)...need to check to ensure that all borrower genders are non missing (if not we need a borrower gender= missing variable)
	gen male=0
	replace male=1 if borr_gender==1

	* Co-Borrower= 1 (e.g., there is a non-missing co-borrower)
	gen coborrower=0
	replace coborrower=1 if coborr_brth_dt_1!=.

	* Initial Principal Limit (init_prncpl_lmt- look also at init_prncpl_lmt_2)  need to check to ensure that all principal limits are non missing (if not we need a borrower gender= missing variable)
	gen max_claim_amount=init_prncpl_lmt
	replace max_claim_amount=init_prncpl_lmt_2 if max_claim_amount==.

	* Loan term
	gen term_loan=0
	replace term_loan=1 if loan_typ=="01" | loan_typ=="04"

	* Loan tenure
	gen tenure_loan=0
	replace tenure_loan=1 if loan_typ=="03" | loan_typ=="05"

	* Mandatory Obligations amount (mndtry_oblgtns_amt)

	* Repair set aside (rpr_set_aside)

	* Create annualized appreciation
	g percent_val= (((1+val_change)^(1/loan_age))-1)*100
	g percent_predic= (((1+predic_vl)^(1/loan_age))-1)*100

	* Create quadratic variables
	g percent_val_quad=percent_val^2
	g percent_predic_quad=percent_predic^2
	g loan_age_quad=loan_age^2
	g loan_age_yr_quad=loan_age_yr^2
	g borr_age_quad=borr_age_endrs^2

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Note Local Value change type
	g increase_dummy=0
	replace increase_dummy=1 if hpi_diff>0
	g decrease_dummy=0
	replace decrease_dummy=1 if hpi_diff<0

	* Family Structures
	gen married=0
	replace married=1 if coborr_brth_dt_1!=.
	gen single_male=0
	replace single_male=1 if coborr_brth_dt_1==. & borr_gender==1

	keep if origin_yr>2002
	drop if borr_age_endrs<0

	* Check for ARM
	gen arm=0
	replace arm=1 if rt_typ!="F"

	*Check for FRM
	gen frm=0
	replace frm=1 if rt_typ=="F"

	* Fico to mean creation
	egen fico_mean=mean(fico_orig)
	g fico_mean_diff=fico_orig-fico_mean

	* Generate Max Claim Amount & change to in the thousands
	replace max_claim_amount=max_claim_amount/1000

	gen mx_clm_amnt150=0
	replace mx_clm_amnt150=1 if max_claim_amount<=150
	label var mx_clm_amnt150 "max claim amount<150k"
	g mx_clm_amnt150_inter=mx_clm_amnt150*max_claim_amount

	gen mx_clm_amnt300=0
	replace mx_clm_amnt300=1 if max_claim_amount>150 & max_claim_amount<=300
	label var mx_clm_amnt300 "max claim amount 150k<300k"
	g mx_clm_amnt300_inter=mx_clm_amnt300*max_claim_amount

	gen mx_clm_amnt300_up=0
	replace mx_clm_amnt300_up=1 if max_claim_amount>300
	label var mx_clm_amnt300_up "max claim amount over 300k"
	g mx_clm_amnt300_up_inter=mx_clm_amnt300_up*max_claim_amount

	* Post 2008 Dummy 
	gen post_2008=0
	replace post_2008=1 if origin_yr>=2009

	* Pre 2009 Dummy
	gen pre_2009=0
	replace pre_2009=1  if origin_yr<2009

	* Zip Price Difference 
	gen zip_price_diff=orig_aprsl/aprsl_median_hv_zip
	gen metro_price_diff=orig_aprsl/aprsl_median_hv_metro

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009


	*Gen Borrower Age Categores
	g borr_age_cat=0
	replace borr_age_cat=1 if borr_age<=65 & borr_age>60
	replace borr_age_cat=2 if borr_age<=70 & borr_age>65
	replace borr_age_cat=3 if borr_age<=75 & borr_age>70
	replace borr_age_cat=4 if borr_age<=80 & borr_age>75
	replace borr_age_cat=5 if borr_age<=85 & borr_age>80
	replace borr_age_cat=6 if borr_age<=90 & borr_age>85
	replace borr_age_cat=7 if borr_age>90

	label define borr_age_cat 1 "60-65" 2 "66-70" 3 "71-75" 4 "76-80" 5 "81-85" 6 "86-90" 7 "Over 90"

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Do not lose observations due to zip and metro variables
	replace zip_price_diff=0 if zip_price_diff==.
	replace metro_price_diff=0 if metro_price_diff==.
	replace  arm_pct_cashdd_post_2008=0 if  arm_pct_cashdd_post_2008==.
	replace pct_cashdd_pre_2009=0 if pct_cashdd_pre_2009==.

	eststo: regress percent_val percent_predic i.origin_yr loan_age
	eststo: regress percent_val percent_predic i.origin_yr loan_age_quad
	eststo: regress percent_val percent_predic i.origin_yr i.loan_age_yr
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad fico_orig
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad fico_orig missing_fico_orig
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad fico_change	
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad married male
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad rpr_set_aside
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad term_loan tenure_loan
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad borr_age
	eststo: regress percent_val percent_predic i.origin_yr ib7.borr_age_cat##c.loan_age loan_age_quad
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad c.max_claim_amount#i.origin_yr	
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad zip_price_diff
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad zip_price_diff max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad metro_price_diff
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad metro_price_diff max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad zip_price_diff metro_price_diff max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr fico_orig missing_fico_orig married male rpr_set_aside term_loan tenure_loan ib7.borr_age_cat##c.loan_age loan_age_quad mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress percent_val percent_predic i.origin_yr i.loan_age_yr fico_orig missing_fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress percent_val percent_predic i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan ib7.borr_age_cat##c.loan_age loan_age_quad mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress percent_val percent_predic i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change		

	esttab using ${output}`Y'_spec1_allloans.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 1 - Short Sale - Total Appreciation)
	esttab using ${output}`Y'_spec1_allloans.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 1 - Short Sale - Total Appreciation)
	esttab using ${output}`Y'_spec1_allloans_tstat.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 1 - Short Sale - Total Appreciation)
	esttab using ${output}`Y'_spec1_allloans_tstat.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 1 - Short Sale - Total Appreciation)

	eststo clear

	restore

	*** REO Sale

	preserve

	keep if FailureType==3

	* (total appreciation – percent predicted)


	* Generate total appreciation variables to match those of the precoded regression
	g percent_val=val_change*100
	g percent_predic=predic_vl*100

	* Borrower= Male (borr_gender==1)...need to check to ensure that all borrower genders are non missing (if not we need a borrower gender= missing variable)
	gen male=0
	replace male=1 if borr_gender==1

	* Co-Borrower= 1 (e.g., there is a non-missing co-borrower)
	gen coborrower=0
	replace coborrower=1 if coborr_brth_dt_1!=.

	* Initial Principal Limit (init_prncpl_lmt- look also at init_prncpl_lmt_2)  need to check to ensure that all principal limits are non missing (if not we need a borrower gender= missing variable)
	gen max_claim_amount=init_prncpl_lmt
	replace max_claim_amount=init_prncpl_lmt_2 if max_claim_amount==.

	* Loan term
	gen term_loan=0
	replace term_loan=1 if loan_typ=="01" | loan_typ=="04"

	* Loan tenure
	gen tenure_loan=0
	replace tenure_loan=1 if loan_typ=="03" | loan_typ=="05"

	* Mandatory Obligations amount (mndtry_oblgtns_amt)

	* Repair set aside (rpr_set_aside)

	* Create annualized appreciation
	g percent_val= (((1+val_change)^(1/loan_age))-1)*100
	g percent_predic= (((1+predic_vl)^(1/loan_age))-1)*100

	* Create quadratic variables
	g percent_val_quad=percent_val^2
	g percent_predic_quad=percent_predic^2
	g loan_age_quad=loan_age^2
	g loan_age_yr_quad=loan_age_yr^2
	g borr_age_quad=borr_age_endrs^2

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Note Local Value change type
	g increase_dummy=0
	replace increase_dummy=1 if hpi_diff>0
	g decrease_dummy=0
	replace decrease_dummy=1 if hpi_diff<0

	* Family Structures
	gen married=0
	replace married=1 if coborr_brth_dt_1!=.
	gen single_male=0
	replace single_male=1 if coborr_brth_dt_1==. & borr_gender==1

	keep if origin_yr>2002
	drop if borr_age_endrs<0

	* Check for ARM
	gen arm=0
	replace arm=1 if rt_typ!="F"

	*Check for FRM
	gen frm=0
	replace frm=1 if rt_typ=="F"

	* Fico to mean creation
	egen fico_mean=mean(fico_orig)
	g fico_mean_diff=fico_orig-fico_mean

	* Generate Max Claim Amount & change to in the thousands
	replace max_claim_amount=max_claim_amount/1000

	gen mx_clm_amnt150=0
	replace mx_clm_amnt150=1 if max_claim_amount<=150
	label var mx_clm_amnt150 "max claim amount<150k"
	g mx_clm_amnt150_inter=mx_clm_amnt150*max_claim_amount

	gen mx_clm_amnt300=0
	replace mx_clm_amnt300=1 if max_claim_amount>150 & max_claim_amount<=300
	label var mx_clm_amnt300 "max claim amount 150k<300k"
	g mx_clm_amnt300_inter=mx_clm_amnt300*max_claim_amount

	gen mx_clm_amnt300_up=0
	replace mx_clm_amnt300_up=1 if max_claim_amount>300
	label var mx_clm_amnt300_up "max claim amount over 300k"
	g mx_clm_amnt300_up_inter=mx_clm_amnt300_up*max_claim_amount

	* Post 2008 Dummy 
	gen post_2008=0
	replace post_2008=1 if origin_yr>=2009

	* Pre 2009 Dummy
	gen pre_2009=0
	replace pre_2009=1  if origin_yr<2009

	* Zip Price Difference 
	gen zip_price_diff=orig_aprsl/aprsl_median_hv_zip
	gen metro_price_diff=orig_aprsl/aprsl_median_hv_metro

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	*Gen Borrower Age Categores
	g borr_age_cat=0
	replace borr_age_cat=1 if borr_age<=65 & borr_age>60
	replace borr_age_cat=2 if borr_age<=70 & borr_age>65
	replace borr_age_cat=3 if borr_age<=75 & borr_age>70
	replace borr_age_cat=4 if borr_age<=80 & borr_age>75
	replace borr_age_cat=5 if borr_age<=85 & borr_age>80
	replace borr_age_cat=6 if borr_age<=90 & borr_age>85
	replace borr_age_cat=7 if borr_age>90

	label define borr_age_cat 1 "60-65" 2 "66-70" 3 "71-75" 4 "76-80" 5 "81-85" 6 "86-90" 7 "Over 90"

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Do not lose observations due to zip and metro variables
	replace zip_price_diff=0 if zip_price_diff==.
	replace metro_price_diff=0 if metro_price_diff==.
	replace  arm_pct_cashdd_post_2008=0 if  arm_pct_cashdd_post_2008==.
	replace pct_cashdd_pre_2009=0 if pct_cashdd_pre_2009==.

	eststo: regress percent_val percent_predic i.origin_yr loan_age
	eststo: regress percent_val percent_predic i.origin_yr loan_age_quad
	eststo: regress percent_val percent_predic i.origin_yr i.loan_age_yr
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad fico_orig
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad fico_orig missing_fico_orig
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad fico_change	
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad married male
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad rpr_set_aside
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad term_loan tenure_loan
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad borr_age
	eststo: regress percent_val percent_predic i.origin_yr ib7.borr_age_cat##c.loan_age loan_age_quad
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad c.max_claim_amount#i.origin_yr	
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad zip_price_diff
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad zip_price_diff max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad metro_price_diff
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad metro_price_diff max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad zip_price_diff metro_price_diff max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr fico_orig missing_fico_orig married male rpr_set_aside term_loan tenure_loan ib7.borr_age_cat##c.loan_age loan_age_quad mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress percent_val percent_predic i.origin_yr i.loan_age_yr fico_orig missing_fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress percent_val percent_predic i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan ib7.borr_age_cat##c.loan_age loan_age_quad mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress percent_val percent_predic i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change		

	esttab using ${output}`Y'_spec1_foreclosed.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 1 - REO Sale - Total Appreciation)
	esttab using ${output}`Y'_spec1_foreclosed.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 1 - REO Sale - Total Appreciation)
	esttab using ${output}`Y'_spec1_foreclosed_tstat.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 1 - REO Sale - Total Appreciation)
	esttab using ${output}`Y'_spec1_foreclosed_tstat.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 1 - REO Sale - Total Appreciation)

	eststo clear

	restore

	*** Borrower Sale

	preserve

	* (total appreciation – percent predicted)

	drop if FailureType==3

	* (total appreciation – percent predicted)


	* Generate total appreciation variables to match those of the precoded regression
	g percent_val=val_change*100
	g percent_predic=predic_vl*100

	* Borrower= Male (borr_gender==1)...need to check to ensure that all borrower genders are non missing (if not we need a borrower gender= missing variable)
	gen male=0
	replace male=1 if borr_gender==1

	* Co-Borrower= 1 (e.g., there is a non-missing co-borrower)
	gen coborrower=0
	replace coborrower=1 if coborr_brth_dt_1!=.

	* Initial Principal Limit (init_prncpl_lmt- look also at init_prncpl_lmt_2)  need to check to ensure that all principal limits are non missing (if not we need a borrower gender= missing variable)
	gen max_claim_amount=init_prncpl_lmt
	replace max_claim_amount=init_prncpl_lmt_2 if max_claim_amount==.

	* Loan term
	gen term_loan=0
	replace term_loan=1 if loan_typ=="01" | loan_typ=="04"

	* Loan tenure
	gen tenure_loan=0
	replace tenure_loan=1 if loan_typ=="03" | loan_typ=="05"

	* Mandatory Obligations amount (mndtry_oblgtns_amt)

	* Repair set aside (rpr_set_aside)

	* Create annualized appreciation
	g percent_val= (((1+val_change)^(1/loan_age))-1)*100
	g percent_predic= (((1+predic_vl)^(1/loan_age))-1)*100

	* Create quadratic variables
	g percent_val_quad=percent_val^2
	g percent_predic_quad=percent_predic^2
	g loan_age_quad=loan_age^2
	g loan_age_yr_quad=loan_age_yr^2
	g borr_age_quad=borr_age_endrs^2

	* Note Local Value change type
	g increase_dummy=0
	replace increase_dummy=1 if hpi_diff>0
	g decrease_dummy=0
	replace decrease_dummy=1 if hpi_diff<0

	* Family Structures
	gen married=0
	replace married=1 if coborr_brth_dt_1!=.
	gen single_male=0
	replace single_male=1 if coborr_brth_dt_1==. & borr_gender==1

	keep if origin_yr>2002
	drop if borr_age_endrs<0

	* Check for ARM
	gen arm=0
	replace arm=1 if rt_typ!="F"

	*Check for FRM
	gen frm=0
	replace frm=1 if rt_typ=="F"

	* Fico to mean creation
	egen fico_mean=mean(fico_orig)
	g fico_mean_diff=fico_orig-fico_mean

	* Generate Max Claim Amount & change to in the thousands
	replace max_claim_amount=max_claim_amount/1000

	gen mx_clm_amnt150=0
	replace mx_clm_amnt150=1 if max_claim_amount<=150
	label var mx_clm_amnt150 "max claim amount<150k"
	g mx_clm_amnt150_inter=mx_clm_amnt150*max_claim_amount

	gen mx_clm_amnt300=0
	replace mx_clm_amnt300=1 if max_claim_amount>150 & max_claim_amount<=300
	label var mx_clm_amnt300 "max claim amount 150k<300k"
	g mx_clm_amnt300_inter=mx_clm_amnt300*max_claim_amount

	gen mx_clm_amnt300_up=0
	replace mx_clm_amnt300_up=1 if max_claim_amount>300
	label var mx_clm_amnt300_up "max claim amount over 300k"
	g mx_clm_amnt300_up_inter=mx_clm_amnt300_up*max_claim_amount

	* Post 2008 Dummy 
	gen post_2008=0
	replace post_2008=1 if origin_yr>=2009

	* Pre 2009 Dummy
	gen pre_2009=0
	replace pre_2009=1  if origin_yr<2009

	* Zip Price Difference 
	gen zip_price_diff=orig_aprsl/aprsl_median_hv_zip
	gen metro_price_diff=orig_aprsl/aprsl_median_hv_metro

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009


	*Gen Borrower Age Categores
	g borr_age_cat=0
	replace borr_age_cat=1 if borr_age<=65 & borr_age>60
	replace borr_age_cat=2 if borr_age<=70 & borr_age>65
	replace borr_age_cat=3 if borr_age<=75 & borr_age>70
	replace borr_age_cat=4 if borr_age<=80 & borr_age>75
	replace borr_age_cat=5 if borr_age<=85 & borr_age>80
	replace borr_age_cat=6 if borr_age<=90 & borr_age>85
	replace borr_age_cat=7 if borr_age>90

	label define borr_age_cat 1 "60-65" 2 "66-70" 3 "71-75" 4 "76-80" 5 "81-85" 6 "86-90" 7 "Over 90"

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Do not lose observations due to zip and metro variables
	replace zip_price_diff=0 if zip_price_diff==.
	replace metro_price_diff=0 if metro_price_diff==.
	replace  arm_pct_cashdd_post_2008=0 if  arm_pct_cashdd_post_2008==.
	replace pct_cashdd_pre_2009=0 if pct_cashdd_pre_2009==.

	eststo: regress percent_val percent_predic i.origin_yr loan_age
	eststo: regress percent_val percent_predic i.origin_yr loan_age_quad
	eststo: regress percent_val percent_predic i.origin_yr i.loan_age_yr
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad fico_orig
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad fico_orig missing_fico_orig
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad fico_change	
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad married male
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad rpr_set_aside
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad term_loan tenure_loan
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad borr_age
	eststo: regress percent_val percent_predic i.origin_yr ib7.borr_age_cat##c.loan_age loan_age_quad
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad c.max_claim_amount#i.origin_yr	
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad zip_price_diff
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad zip_price_diff max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad metro_price_diff
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad metro_price_diff max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr loan_age loan_age_quad zip_price_diff metro_price_diff max_claim_amount
	eststo: regress percent_val percent_predic i.origin_yr fico_orig missing_fico_orig married male rpr_set_aside term_loan tenure_loan ib7.borr_age_cat##c.loan_age loan_age_quad mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress percent_val percent_predic i.origin_yr i.loan_age_yr fico_orig missing_fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress percent_val percent_predic i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan ib7.borr_age_cat##c.loan_age loan_age_quad mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress percent_val percent_predic i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_inter mx_clm_amnt300_inter mx_clm_amnt300_up_inter frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change


	esttab using ${output}`Y'_spec1_nonforeclosed.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 1 - Borrower Sale - Total Appreciation)
	esttab using ${output}`Y'_spec1_nonforeclosed.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 1 - Borrower Sale - Total Appreciation)
	esttab using ${output}`Y'_spec1_nonforeclosed_tstat.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 1 - Borrower Sale - Total Appreciation)
	esttab using ${output}`Y'_spec1_nonforeclosed_tstat.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 1 - Borrower Sale - Total Appreciation)

	eststo clear

	restore

end



program define specification2_2


	***** Change Dependent

	*** All Loans

	preserve

	* Borrower= Male (borr_gender==1)...need to check to ensure that all borrower genders are non missing (if not we need a borrower gender= missing variable)
	gen male=0
	replace male=1 if borr_gender==1

	* Co-Borrower= 1 (e.g., there is a non-missing co-borrower)
	gen coborrower=0
	replace coborrower=1 if coborr_brth_dt_1!=.

	* Initial Principal Limit (init_prncpl_lmt- look also at init_prncpl_lmt_2)  need to check to ensure that all principal limits are non missing (if not we need a borrower gender= missing variable)
	gen max_claim_amount=init_prncpl_lmt
	replace max_claim_amount=init_prncpl_lmt_2 if max_claim_amount==.

	* Loan term
	gen term_loan=0
	replace term_loan=1 if loan_typ=="01" | loan_typ=="04"

	* Loan tenure
	gen tenure_loan=0
	replace tenure_loan=1 if loan_typ=="03" | loan_typ=="05"

	* Mandatory Obligations amount (mndtry_oblgtns_amt)

	* Repair set aside (rpr_set_aside)

	* Create annualized appreciation
	g percent_val= (((1+val_change)^(1/loan_age))-1)*100
	g percent_predic= (((1+predic_vl)^(1/loan_age))-1)*100
	replace vl_change=percent_val-percent_predic

	* Create quadratic variables
	g percent_val_quad=percent_val^2
	g loan_age_quad=loan_age^2
	g loan_age_yr_quad=loan_age_yr^2
	g borr_age_quad=borr_age_endrs^2

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig
	replace fico_change=0 if fico_orig==0

	* Note Local Value change type
	g increase_dummy=0
	replace increase_dummy=1 if hpi_diff>0
	g decrease_dummy=0
	replace decrease_dummy=1 if hpi_diff<0

	* Family Structures
	gen married=0
	replace married=1 if coborr_brth_dt_1!=.
	gen single_male=0
	replace single_male=1 if coborr_brth_dt_1==. & borr_gender==1

	keep if origin_yr>2002
	drop if borr_age_endrs<0

	* Check for ARM
	gen arm=0
	replace arm=1 if rt_typ!="F"

	*Check for FRM
	gen frm=0
	replace frm=1 if rt_typ=="F"

	* Fico to mean creation
	egen fico_mean=mean(fico_orig)
	g fico_mean_diff=fico_orig-fico_mean

	* Generate Max Claim Amount & change to in the thousands
	replace max_claim_amount=max_claim_amount/1000

	gen mx_clm_amnt150_dummy=0
	replace mx_clm_amnt150_dummy=1 if max_claim_amount<=150
	label var mx_clm_amnt150 "max claim amount<150k"
	g mx_clm_amnt150_inter=mx_clm_amnt150_dummy*max_claim_amount

	gen mx_clm_amnt300=0
	replace mx_clm_amnt300=1 if max_claim_amount>150 & max_claim_amount<=300
	label var mx_clm_amnt300 "max claim amount 150k<300k"
	g mx_clm_amnt300_inter=mx_clm_amnt300*max_claim_amount

	gen mx_clm_amnt300_up=0
	replace mx_clm_amnt300_up=1 if max_claim_amount>300
	label var mx_clm_amnt300_up "max claim amount over 300k"
	g mx_clm_amnt300_up_inter=mx_clm_amnt300_up*max_claim_amount

	* Post 2008 Dummy 
	gen post_2008=0
	replace post_2008=1 if origin_yr>=2009

	* Generate New Max Claim Amount variables
	gen mx_clm_amntover150_dummy=0
	replace mx_clm_amntover150_dummy=1 if max_claim_amount>150
	g mx_clm_amntover150_inter=mx_clm_amntover150_dummy*max_claim_amount
	g mx_clm_amnt150_dummy_post2008=mx_clm_amnt150_dummy *post_2008
	g mx_clm_amnt150_inter_post2008=mx_clm_amnt150_inter *post_2008
	g mx_clm_amntover150_post2008=mx_clm_amntover150_inter*post_2008

	* Pre 2009 Dummy
	gen pre_2009=0
	replace pre_2009=1  if origin_yr<2009

	* Zip Price Difference 
	gen zip_price_diff=orig_aprsl/aprsl_median_hv_zip
	gen metro_price_diff=orig_aprsl/aprsl_median_hv_metro

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009


	*Gen Borrower Age Categores
	g borr_age_cat=0
	replace borr_age_cat=1 if borr_age<=65 & borr_age>60
	replace borr_age_cat=2 if borr_age<=70 & borr_age>65
	replace borr_age_cat=3 if borr_age<=75 & borr_age>70
	replace borr_age_cat=4 if borr_age<=80 & borr_age>75
	replace borr_age_cat=5 if borr_age<=85 & borr_age>80
	replace borr_age_cat=6 if borr_age<=90 & borr_age>85
	replace borr_age_cat=7 if borr_age>90

	label define borr_age_cat 1 "60-65" 2 "66-70" 3 "71-75" 4 "76-80" 5 "81-85" 6 "86-90" 7 "Over 90"

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Do not lose observations due to zip and metro variables
	replace zip_price_diff=0 if zip_price_diff==.
	replace metro_price_diff=0 if metro_price_diff==.
	replace  arm_pct_cashdd_post_2008=0 if  arm_pct_cashdd_post_2008==.
	replace pct_cashdd_pre_2009=0 if pct_cashdd_pre_2009==.

	eststo: regress vl_change i.origin_yr loan_age
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad
	eststo: regress vl_change i.origin_yr i.loan_age_yr
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad fico_orig
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad fico_change
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad married male
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad rpr_set_aside
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad max_claim_amount
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad term_loan tenure_loan
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad borr_age 
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mx_clm_amntover150_post2008
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff max_claim_amount
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad metro_price_diff
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad metro_price_diff max_claim_amount
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff metro_price_diff max_claim_amount
	eststo: regress vl_change i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mx_clm_amntover150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress vl_change i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mx_clm_amntover150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change

	esttab using ${output}`Y'_spec2_allloans.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 2 - All Sales - Total Appreciation)
	esttab using ${output}`Y'_spec2_allloans.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 2 - All Sales - Total Appreciation)
	esttab using ${output}`Y'_spec2_allloans_tstat.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 2 - All Sales - Total Appreciation)
	esttab using ${output}`Y'_spec2_allloans_tstat.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 2 - All Sale - Total Appreciation)

	eststo clear

	restore

	*** REO Sale

	preserve

	keep if FailureType==3

	* (total appreciation – percent predicted)

	* Borrower= Male (borr_gender==1)...need to check to ensure that all borrower genders are non missing (if not we need a borrower gender= missing variable)
	gen male=0
	replace male=1 if borr_gender==1

	* Co-Borrower= 1 (e.g., there is a non-missing co-borrower)
	gen coborrower=0
	replace coborrower=1 if coborr_brth_dt_1!=.

	* Initial Principal Limit (init_prncpl_lmt- look also at init_prncpl_lmt_2)  need to check to ensure that all principal limits are non missing (if not we need a borrower gender= missing variable)
	gen max_claim_amount=init_prncpl_lmt
	replace max_claim_amount=init_prncpl_lmt_2 if max_claim_amount==.

	* Loan term
	gen term_loan=0
	replace term_loan=1 if loan_typ=="01" | loan_typ=="04"

	* Loan tenure
	gen tenure_loan=0
	replace tenure_loan=1 if loan_typ=="03" | loan_typ=="05"

	* Mandatory Obligations amount (mndtry_oblgtns_amt)

	* Repair set aside (rpr_set_aside)

	* Create annualized appreciation
	g percent_val= (((1+val_change)^(1/loan_age))-1)*100
	g percent_predic= (((1+predic_vl)^(1/loan_age))-1)*100
	replace vl_change=percent_val-percent_predic

	* Create quadratic variables
	g percent_val_quad=percent_val^2
	g loan_age_quad=loan_age^2
	g loan_age_yr_quad=loan_age_yr^2
	g borr_age_quad=borr_age_endrs^2

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Note Local Value change type
	g increase_dummy=0
	replace increase_dummy=1 if hpi_diff>0
	g decrease_dummy=0
	replace decrease_dummy=1 if hpi_diff<0

	* Family Structures
	gen married=0
	replace married=1 if coborr_brth_dt_1!=.
	gen single_male=0
	replace single_male=1 if coborr_brth_dt_1==. & borr_gender==1

	keep if origin_yr>2002
	drop if borr_age_endrs<0

	* Check for ARM
	gen arm=0
	replace arm=1 if rt_typ!="F"

	*Check for FRM
	gen frm=0
	replace frm=1 if rt_typ=="F"

	* Fico to mean creation
	egen fico_mean=mean(fico_orig)
	g fico_mean_diff=fico_orig-fico_mean

	* Generate Max Claim Amount & change to in the thousands
	replace max_claim_amount=max_claim_amount/1000

	gen mx_clm_amnt150_dummy=0
	replace mx_clm_amnt150_dummy=1 if max_claim_amount<=150
	label var mx_clm_amnt150 "max claim amount<150k"
	g mx_clm_amnt150_inter=mx_clm_amnt150_dummy*max_claim_amount

	gen mx_clm_amnt300=0
	replace mx_clm_amnt300=1 if max_claim_amount>150 & max_claim_amount<=300
	label var mx_clm_amnt300 "max claim amount 150k<300k"
	g mx_clm_amnt300_inter=mx_clm_amnt300*max_claim_amount

	gen mx_clm_amnt300_up=0
	replace mx_clm_amnt300_up=1 if max_claim_amount>300
	label var mx_clm_amnt300_up "max claim amount over 300k"
	g mx_clm_amnt300_up_inter=mx_clm_amnt300_up*max_claim_amount

	* Post 2008 Dummy 
	gen post_2008=0
	replace post_2008=1 if origin_yr>=2009

	* Generate New Max Claim Amount variables
	gen mx_clm_amntover150_dummy=0
	replace mx_clm_amntover150_dummy=1 if max_claim_amount>150
	g mx_clm_amntover150_inter=mx_clm_amntover150_dummy*max_claim_amount
	g mx_clm_amnt150_dummy_post2008=mx_clm_amnt150_dummy *post_2008
	g mx_clm_amnt150_inter_post2008=mx_clm_amnt150_inter *post_2008
	g mx_clm_amntover150_post2008=mx_clm_amntover150_inter*post_2008

	* Pre 2009 Dummy
	gen pre_2009=0
	replace pre_2009=1  if origin_yr<2009

	* Zip Price Difference 
	gen zip_price_diff=orig_aprsl/aprsl_median_hv_zip
	gen metro_price_diff=orig_aprsl/aprsl_median_hv_metro

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009


	*Gen Borrower Age Categores
	g borr_age_cat=0
	replace borr_age_cat=1 if borr_age<=65 & borr_age>60
	replace borr_age_cat=2 if borr_age<=70 & borr_age>65
	replace borr_age_cat=3 if borr_age<=75 & borr_age>70
	replace borr_age_cat=4 if borr_age<=80 & borr_age>75
	replace borr_age_cat=5 if borr_age<=85 & borr_age>80
	replace borr_age_cat=6 if borr_age<=90 & borr_age>85
	replace borr_age_cat=7 if borr_age>90

	label define borr_age_cat 1 "60-65" 2 "66-70" 3 "71-75" 4 "76-80" 5 "81-85" 6 "86-90" 7 "Over 90"

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Do not lose observations due to zip and metro variables
	replace zip_price_diff=0 if zip_price_diff==.
	replace metro_price_diff=0 if metro_price_diff==.
	replace  arm_pct_cashdd_post_2008=0 if  arm_pct_cashdd_post_2008==.
	replace pct_cashdd_pre_2009=0 if pct_cashdd_pre_2009==.


	eststo: regress vl_change i.origin_yr loan_age
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad
	eststo: regress vl_change i.origin_yr i.loan_age_yr
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad fico_orig
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad fico_change
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad married male
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad rpr_set_aside
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad max_claim_amount
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad term_loan tenure_loan
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad borr_age 
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mx_clm_amntover150_post2008
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff max_claim_amount
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad metro_price_diff
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad metro_price_diff max_claim_amount
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff metro_price_diff max_claim_amount
	eststo: regress vl_change i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mx_clm_amntover150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress vl_change i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mx_clm_amntover150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change

	esttab using ${output}`Y'_spec2_foreclosed.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 3 - REO Sale - Total Appreciation)
	esttab using ${output}`Y'_spec2_foreclosed.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 3 - REO Sale - Total Appreciation)
	esttab using ${output}`Y'_spec2_foreclosed_tstat.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 3 - REO Sale - Total Appreciation)
	esttab using ${output}`Y'_spec2_foreclosed_tstat.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 3 - REO Sale - Total Appreciation)

	eststo clear

	restore

	*** Borrower Sale

	preserve

	* (total appreciation – percent predicted)

	drop if FailureType==3


	* Borrower= Male (borr_gender==1)...need to check to ensure that all borrower genders are non missing (if not we need a borrower gender= missing variable)
	gen male=0
	replace male=1 if borr_gender==1

	* Co-Borrower= 1 (e.g., there is a non-missing co-borrower)
	gen coborrower=0
	replace coborrower=1 if coborr_brth_dt_1!=.

	* Initial Principal Limit (init_prncpl_lmt- look also at init_prncpl_lmt_2)  need to check to ensure that all principal limits are non missing (if not we need a borrower gender= missing variable)
	gen max_claim_amount=init_prncpl_lmt
	replace max_claim_amount=init_prncpl_lmt_2 if max_claim_amount==.

	* Loan term
	gen term_loan=0
	replace term_loan=1 if loan_typ=="01" | loan_typ=="04"

	* Loan tenure
	gen tenure_loan=0
	replace tenure_loan=1 if loan_typ=="03" | loan_typ=="05"

	* Mandatory Obligations amount (mndtry_oblgtns_amt)

	* Repair set aside (rpr_set_aside)

	* Create annualized appreciation
	g percent_val= (((1+val_change)^(1/loan_age))-1)*100
	g percent_predic= (((1+predic_vl)^(1/loan_age))-1)*100
	replace vl_change=percent_val-percent_predic

	* Create quadratic variables
	g percent_val_quad=percent_val^2
	g loan_age_quad=loan_age^2
	g loan_age_yr_quad=loan_age_yr^2
	g borr_age_quad=borr_age_endrs^2

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Note Local Value change type
	g increase_dummy=0
	replace increase_dummy=1 if hpi_diff>0
	g decrease_dummy=0
	replace decrease_dummy=1 if hpi_diff<0

	* Family Structures
	gen married=0
	replace married=1 if coborr_brth_dt_1!=.
	gen single_male=0
	replace single_male=1 if coborr_brth_dt_1==. & borr_gender==1

	keep if origin_yr>2002
	drop if borr_age_endrs<0

	* Check for ARM
	gen arm=0
	replace arm=1 if rt_typ!="F"

	*Check for FRM
	gen frm=0
	replace frm=1 if rt_typ=="F"

	* Fico to mean creation
	egen fico_mean=mean(fico_orig)
	g fico_mean_diff=fico_orig-fico_mean

	* Generate Max Claim Amount & change to in the thousands
	replace max_claim_amount=max_claim_amount/1000

	gen mx_clm_amnt150_dummy=0
	replace mx_clm_amnt150_dummy=1 if max_claim_amount<=150
	label var mx_clm_amnt150 "max claim amount<150k"
	g mx_clm_amnt150_inter=mx_clm_amnt150_dummy*max_claim_amount

	gen mx_clm_amnt300=0
	replace mx_clm_amnt300=1 if max_claim_amount>150 & max_claim_amount<=300
	label var mx_clm_amnt300 "max claim amount 150k<300k"
	g mx_clm_amnt300_inter=mx_clm_amnt300*max_claim_amount

	gen mx_clm_amnt300_up=0
	replace mx_clm_amnt300_up=1 if max_claim_amount>300
	label var mx_clm_amnt300_up "max claim amount over 300k"
	g mx_clm_amnt300_up_inter=mx_clm_amnt300_up*max_claim_amount

	* Post 2008 Dummy 
	gen post_2008=0
	replace post_2008=1 if origin_yr>=2009

	* Generate New Max Claim Amount variables
	gen mx_clm_amntover150_dummy=0
	replace mx_clm_amntover150_dummy=1 if max_claim_amount>150
	g mx_clm_amntover150_inter=mx_clm_amntover150_dummy*max_claim_amount
	g mx_clm_amnt150_dummy_post2008=mx_clm_amnt150_dummy *post_2008
	g mx_clm_amnt150_inter_post2008=mx_clm_amnt150_inter *post_2008
	g mx_clm_amntover150_post2008=mx_clm_amntover150_inter*post_2008

	* Pre 2009 Dummy
	gen pre_2009=0
	replace pre_2009=1  if origin_yr<2009

	* Zip Price Difference 
	gen zip_price_diff=orig_aprsl/aprsl_median_hv_zip
	gen metro_price_diff=orig_aprsl/aprsl_median_hv_metro

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009


	*Gen Borrower Age Categores
	g borr_age_cat=0
	replace borr_age_cat=1 if borr_age<=65 & borr_age>60
	replace borr_age_cat=2 if borr_age<=70 & borr_age>65
	replace borr_age_cat=3 if borr_age<=75 & borr_age>70
	replace borr_age_cat=4 if borr_age<=80 & borr_age>75
	replace borr_age_cat=5 if borr_age<=85 & borr_age>80
	replace borr_age_cat=6 if borr_age<=90 & borr_age>85
	replace borr_age_cat=7 if borr_age>90

	label define borr_age_cat 1 "60-65" 2 "66-70" 3 "71-75" 4 "76-80" 5 "81-85" 6 "86-90" 7 "Over 90"

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Do not lose observations due to zip and metro variables
	replace zip_price_diff=0 if zip_price_diff==.
	replace metro_price_diff=0 if metro_price_diff==.
	replace  arm_pct_cashdd_post_2008=0 if  arm_pct_cashdd_post_2008==.
	replace pct_cashdd_pre_2009=0 if pct_cashdd_pre_2009==.

	eststo: regress vl_change i.origin_yr loan_age
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad
	eststo: regress vl_change i.origin_yr i.loan_age_yr
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad fico_orig
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad fico_change
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad married male
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad rpr_set_aside
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad max_claim_amount
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad term_loan tenure_loan
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad borr_age 
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mx_clm_amntover150_post2008
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff max_claim_amount
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad metro_price_diff
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad metro_price_diff max_claim_amount
	eststo: regress vl_change i.origin_yr loan_age loan_age_quad zip_price_diff metro_price_diff max_claim_amount
	eststo: regress vl_change i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mx_clm_amntover150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: regress vl_change i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_dummy mx_clm_amnt150_inter mx_clm_amntover150_inter mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mx_clm_amntover150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change


	esttab using ${output}`Y'_spec2_nonforeclosed.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 2 - Borrower Sale - Total Appreciation)
	esttab using ${output}`Y'_spec2_nonforeclosed.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 2 - Borrower Sale - Total Appreciation)
	esttab using ${output}`Y'_spec2_nonforeclosed_tstat.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 2 - Borrower Sale - Total Appreciation)
	esttab using ${output}`Y'_spec2_nonforeclosed_tstat.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 2 - Borrower Sale - Total Appreciation)

	eststo clear

	restore

	** Foreclose Dependent

	preserve

	gen foreclose=0
	replace foreclose=1 if FailureType==3

	* Borrower= Male (borr_gender==1)...need to check to ensure that all borrower genders are non missing (if not we need a borrower gender= missing variable)
	gen male=0
	replace male=1 if borr_gender==1

	* Co-Borrower= 1 (e.g., there is a non-missing co-borrower)
	gen coborrower=0
	replace coborrower=1 if coborr_brth_dt_1!=.

	* Initial Principal Limit (init_prncpl_lmt- look also at init_prncpl_lmt_2)  need to check to ensure that all principal limits are non missing (if not we need a borrower gender= missing variable)
	gen max_claim_amount=init_prncpl_lmt
	replace max_claim_amount=init_prncpl_lmt_2 if max_claim_amount==.

	* Loan term
	gen term_loan=0
	replace term_loan=1 if loan_typ=="01" | loan_typ=="04"

	* Loan tenure
	gen tenure_loan=0
	replace tenure_loan=1 if loan_typ=="03" | loan_typ=="05"

	* Mandatory Obligations amount (mndtry_oblgtns_amt)

	* Repair set aside (rpr_set_aside)

	* Create annualized appreciation
	g percent_val= (((1+val_change)^(1/loan_age))-1)*100
	g percent_predic= (((1+predic_vl)^(1/loan_age))-1)*100
	replace vl_change=percent_val-percent_predic

	* Create quadratic variables
	g percent_val_quad=percent_val^2
	g loan_age_quad=loan_age^2
	g loan_age_yr_quad=loan_age_yr^2
	g borr_age_quad=borr_age_endrs^2

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Note Local Value change type
	g increase_dummy=0
	replace increase_dummy=1 if hpi_diff>0
	g decrease_dummy=0
	replace decrease_dummy=1 if hpi_diff<0

	* Family Structures
	gen married=0
	replace married=1 if coborr_brth_dt_1!=.
	gen single_male=0
	replace single_male=1 if coborr_brth_dt_1==. & borr_gender==1

	keep if origin_yr>2002
	drop if borr_age_endrs<0

	* Check for ARM
	gen arm=0
	replace arm=1 if rt_typ!="F"

	*Check for FRM
	gen frm=0
	replace frm=1 if rt_typ=="F"

	* Fico to mean creation
	egen fico_mean=mean(fico_orig)
	g fico_mean_diff=fico_orig-fico_mean

	* Generate Max Claim Amount & change to in the thousands
	replace max_claim_amount=max_claim_amount/1000

	gen mx_clm_amnt150_dummy=0
	replace mx_clm_amnt150_dummy=1 if max_claim_amount<=150
	label var mx_clm_amnt150 "max claim amount<150k"
	g mx_clm_amnt150_inter=mx_clm_amnt150_dummy*max_claim_amount

	gen mx_clm_amnt300=0
	replace mx_clm_amnt300=1 if max_claim_amount>150 & max_claim_amount<=300
	label var mx_clm_amnt300 "max claim amount 150k<300k"
	g mx_clm_amnt300_inter=mx_clm_amnt300*max_claim_amount

	gen mx_clm_amnt300_up=0
	replace mx_clm_amnt300_up=1 if max_claim_amount>300
	label var mx_clm_amnt300_up "max claim amount over 300k"
	g mx_clm_amnt300_up_inter=mx_clm_amnt300_up*max_claim_amount

	* Post 2008 Dummy 
	gen post_2008=0
	replace post_2008=1 if origin_yr>=2009

	* Generate New Max Claim Amount variables
	gen mx_clm_amntover150_dummy=0
	replace mx_clm_amntover150_dummy=1 if max_claim_amount>150
	g mx_clm_amntover150_inter=mx_clm_amntover150_dummy*max_claim_amount
	g mx_clm_amnt150_dummy_post2008=mx_clm_amnt150_dummy *post_2008
	g mx_clm_amnt150_inter_post2008=mx_clm_amnt150_inter *post_2008
	g mx_clm_amntover150_post2008=mx_clm_amntover150_inter*post_2008

	* Pre 2009 Dummy
	gen pre_2009=0
	replace pre_2009=1  if origin_yr<2009

	* Zip Price Difference 
	gen zip_price_diff=orig_aprsl/aprsl_median_hv_zip
	gen metro_price_diff=orig_aprsl/aprsl_median_hv_metro

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009

	* Borrower Age Variable creation
	g borr_age=borr_age_endrs
	replace borr_age=coborr_age if coborr_age<borr_age_endrs
	drop if borr_age_endrs>120

	* Gen interaction terms so categorry outcome is also a Dummy
	g frm_post_2008=frm*post_2008 
	g arm_pct_cashdd_post_2008=arm*fm_pct_cashdd*post_2008 
	g pct_cashdd_pre_2009=fm_pct_cashdd*pre_2009


	*Gen Borrower Age Categores
	g borr_age_cat=0
	replace borr_age_cat=1 if borr_age<=65 & borr_age>60
	replace borr_age_cat=2 if borr_age<=70 & borr_age>65
	replace borr_age_cat=3 if borr_age<=75 & borr_age>70
	replace borr_age_cat=4 if borr_age<=80 & borr_age>75
	replace borr_age_cat=5 if borr_age<=85 & borr_age>80
	replace borr_age_cat=6 if borr_age<=90 & borr_age>85
	replace borr_age_cat=7 if borr_age>90

	label define borr_age_cat 1 "60-65" 2 "66-70" 3 "71-75" 4 "76-80" 5 "81-85" 6 "86-90" 7 "Over 90"

	* Create Change in credit score variables
	gen fico_change=fico_sale-fico_orig

	* Do not lose observations due to zip and metro variables
	replace zip_price_diff=0 if zip_price_diff==.
	replace metro_price_diff=0 if metro_price_diff==.
	replace  arm_pct_cashdd_post_2008=0 if  arm_pct_cashdd_post_2008==.
	replace pct_cashdd_pre_2009=0 if pct_cashdd_pre_2009==.


	eststo: logit foreclose percent_predic
	eststo: logit foreclose i.origin_yr loan_age
	eststo: logit foreclose i.origin_yr loan_age loan_age_quad
	eststo: logit foreclose i.origin_yr i.loan_age_yr
	eststo: logit foreclose i.origin_yr loan_age loan_age_quad fico_orig fico_change
	eststo: logit foreclose i.origin_yr loan_age loan_age_quad married male borr_age 
	eststo: logit foreclose i.origin_yr loan_age loan_age_quad rpr_set_aside
	eststo: logit foreclose i.origin_yr loan_age loan_age_quad max_claim_amount zip_price_diff metro_price_diff
	eststo: logit foreclose i.origin_yr loan_age loan_age_quad zip_price_diff mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008
	eststo: logit foreclose i.origin_yr loan_age loan_age_quad zip_price_diff mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150
	eststo: logit foreclose i.origin_yr loan_age loan_age_quad frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 term_loan tenure_loan
	eststo: logit foreclose i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change
	eststo: logit foreclose i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff metro_price_diff fico_change
	eststo: logit foreclose percent_predic i.origin_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age loan_age loan_age_quad mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change
	eststo: logit foreclose percent_predic i.origin_yr i.loan_age_yr fico_orig married male rpr_set_aside term_loan tenure_loan borr_age mx_clm_amnt150_dummy mx_clm_amnt150_inter mca_over150_minus150 mx_clm_amnt150_dummy_post2008 mx_clm_amnt150_inter_post2008 mca_over150_minus150_post2008 frm_post_2008 arm_pct_cashdd_post_2008 pct_cashdd_pre_2009 zip_price_diff fico_change


	esttab using ${output}`Y'_spec2_foreclosed_dependent_linear.csv, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 1 - REO Sale Dependent - Total Appreciation)
	esttab using ${output}`Y'_spec2_foreclosed_dependent_linear.rtf, replace  se(6) nostar b(5) t(2) ar2 label title(`Y' Spec 1 - REO Sale Dependent - Total Appreciation)
	esttab using ${output}`Y'_spec2_foreclosed_dependent_linear_tstat.csv, replace nostar b(5) t(2) ar2 label title(`Y' Spec 1 - REO Sale Dependent - Total Appreciation)
	esttab using ${output}`Y'_spec2_foreclosed_dependent_linear_tstat.rtf, replace nostar b(5) t(2) ar2 label title(`Y' Spec 1 - REO Sale Dependent - Total Appreciation)

	eststo clear


	restore

end

